@@ -36,6 +36,7 @@ def main(args):
         generate_cli_docs(args.out_dir, version)
         generate_redirect(args.out_dir, version, 'datasets.html', 'index.html')
         generate_redirect(args.out_dir, version, 'all.html', 'index.html')
+        generate_downloads(args.out_dir, version)
         generate_css(args.out_dir, version)
         generate_js(args.out_dir, version)
 
@@ -56,6 +57,7 @@ def generate_dataset_page(out_dir, version, top_level, sub_datasets):
     dataset = ir_datasets.registry[top_level]
     documentation = dataset.documentation() if hasattr(dataset, 'documentation') else {}
     with page_template(f'{top_level}.html', out_dir, version, title=documentation.get('pretty_name', top_level), source=f'datasets/{top_level.replace("-", "_")}.py') as out:
+        data_access_section = generate_data_access_section(documentation)
         index = '\n'.join(f'<li><a href="#{name}"><kbd><span class="prefix">{top_level}</span>{name[len(top_level):]}</kbd></a></li>' for name, ds in sub_datasets)
         out.write(f'''
 <div style="font-weight: bold; font-size: 1.1em;">Index</div>
@@ -63,7 +65,9 @@ def generate_dataset_page(out_dir, version, top_level, sub_datasets):
 <li><a href="#{top_level}"><kbd>{top_level}</kbd></a></li>
 {index}
 </ol>
-<hr />
+<div id="Downloads">
+</div>
+{data_access_section}<hr />
 <div class="dataset" id="{top_level}">
 <h3><kbd class="select"><span class="str">"{top_level}"</kdb></h3>
 {generate_dataset(dataset, top_level)}
@@ -77,6 +81,17 @@ def generate_dataset_page(out_dir, version, top_level, sub_datasets):
 {generate_dataset(dataset, name)}
 </div>
 ''')
+        out.write('''
+<script type="text/javascript">
+$(function () {
+    $.ajax({
+        'url': 'https://smac.pub/irdsdlc?ds=''' + top_level + ''''
+    }).done(function (data) {
+        $('#Downloads').append(generateDownloads('Downloadable content', data));
+    });
+});
+</script>
+''')
 
 
 
@@ -196,6 +211,18 @@ bibtex:
         out.seek(0)
         return out.read()
 
+
+def generate_data_access_section(documentation):
+    if 'data_access' not in documentation:
+        return ''
+    return f'''
+<div id="DataAccess">
+<h3>Data Access Information</h3>
+{documentation["data_access"]}
+</div>
+'''
+
+
 def generate_data_format(cls):
     if cls in (str, int, float, bytes):
         return f'<span class="kwd">{cls.__name__}</span>'
@@ -206,7 +233,7 @@ def generate_data_format(cls):
                 args.append(' ...')
             else:
                 args.append(generate_data_format(arg))
-        if cls._name in ('Tuple', 'List'):
+        if cls._name in ('Tuple', 'List', 'Dict'):
             return f'<span class="kwd">{cls._name}</span>[{",".join(args)}]'
     elif tuple in cls.__bases__ and hasattr(cls, '_fields'):
         fields = []
@@ -231,7 +258,7 @@ def generate_data_format(cls):
 def generate_index(out_dir, version):
     with page_template('index.html', out_dir, version, title='Catalog') as out:
         if version == 'master':
-            install = 'git+https://github.com/allenai/ir_datasets.git@master'
+            install = '--upgrade git+https://github.com/allenai/ir_datasets.git'
         elif version.startswith('v'):
             install = f'ir_datasets=={version[1:]}'
         elif not version:
@@ -239,17 +266,22 @@ def generate_index(out_dir, version):
         else:
             raise RuntimeError(f'unknown version {version}')
         index = []
+        jump = []
         for name in sorted(ir_datasets.registry):
             dataset = ir_datasets.registry[name]
             parent = name.split('/')[0]
             if parent != name:
-                ds_name = f'<a href="{parent}.html#{name}"><kbd><span class="prefix">{parent}</span>{name[len(parent):]}</kbd></a>'
+                ds_name = f'<a href="{parent}.html#{name}"><kbd><span class="prefix"><span class="screen-small-hide">{parent}</span><span class="screen-small-show">&hellip;</span></span>{name[len(parent):]}</kbd></a>'
                 tbody = ''
+                row_id = ''
             else:
                 ds_name = f'<a style="font-weight: bold;" href="{parent}.html"><kbd>{parent}</kbd></a></li>'
                 tbody = '</tbody><tbody>'
-            index.append(f'{tbody}<tr><td>{ds_name}</td><td class="center">{emoji(dataset, "docs")}</td><td class="center">{emoji(dataset, "queries")}</td><td class="center">{emoji(dataset, "qrels")}</td><td class="center screen-small-hide">{emoji(dataset, "scoreddocs")}</td><td class="center screen-small-hide">{emoji(dataset, "docpairs")}</td></tr>')
+                row_id = f' id="{parent}"'
+                jump.append(f'<option value="{parent}">{parent}</option>')
+            index.append(f'{tbody}<tr{row_id}><td>{ds_name}</td><td class="center">{emoji(dataset, "docs", parent)}</td><td class="center">{emoji(dataset, "queries", parent)}</td><td class="center">{emoji(dataset, "qrels", parent)}</td><td class="center screen-small-hide">{emoji(dataset, "scoreddocs", parent)}</td><td class="center screen-small-hide">{emoji(dataset, "docpairs", parent)}</td></tr>')
         index = '\n'.join(index)
+        jump = '\n'.join(jump)
         out.write(f'''
 <p>
 <code>ir_datasets</code> provides a common interface to many IR ranking datasets.
@@ -267,11 +299,18 @@ Install with pip:
 
 <ul>
 <li>Colab Tutorials: <a href="https://colab.research.google.com/github/allenai/ir_datasets/blob/master/examples/ir_datasets.ipynb">python</a>, <a href="https://colab.research.google.com/github/allenai/ir_datasets/blob/master/examples/ir_datasets_cli.ipynb">CLI</a></li>
-<li><a href="python.html">Python API Documentation</a></li>
+<li><a href="python.html">Python API Documentation</a> (<a href="python-beta.html">beta version</a>)</li>
 <li><a href="cli.html">CLI Documentation</a></li>
+<li><a href="downloads.html">Download Dashboard</a></li>
+<li><a href="https://github.com/allenai/ir_datasets/blob/master/examples/adding_datasets.ipynb">Adding new datasets</a></li>
+<li><a href="https://arxiv.org/pdf/2103.02280.pdf">ir_datasets SIGIR resource paper</a></li>
 </ul>
 
-<h2>Dataset Index</h2>
+<h2 style="margin-bottom: 4px;">Dataset Index</h2>
+<select id="DatasetJump">
+<option value="">Jump to Dataset...</option>
+{jump}
+</select>
 <p>✅: Data available as automatic download</p>
 <p>⚠️: Data available from a third party</p>
 <table>
@@ -300,6 +339,20 @@ Install with pip:
 <ul>
 {versions}
 </ul>
+<h2>Citation</h2>
+<p>
+When using datasets provided by this package, be sure to properly cite them. Bibtex for each dataset
+can be found on each dataset's documenation page, or in the python interface via
+<kbd>dataset.documentation()['bibtex']</kbd> (when available).
+</p>
+<p>If you use this tool, please cite our <a href="https://arxiv.org/pdf/2103.02280.pdf">SIGIR resource paper</a>:</p>
+<cite class="select">@inproceedings{{macavaney:sigir2021-irds,
+  author = {{MacAvaney, Sean and Yates, Andrew and Feldman, Sergey and Downey, Doug and Cohan, Arman and Goharian, Nazli}},
+  title = {{Simplified Data Wrangling with ir_datasets}},
+  year = {{2021}},
+  booktitle = {{SIGIR}}
+}}
+</cite>
 ''')
 
 
@@ -609,6 +662,296 @@ optmize the order in which documents are retrieved from disk.) Missing documents
 appear in the iterator.
 </p>
 </div>
+''')
+    with page_template('python-beta.html', out_dir, version, title='Beta Python API') as out:
+        out.write(f'''
+<div class="warn">
+This is an experimental version of the Python API, and may be buggy and subject to change in future
+versions. See <a href="python.html">here</a> for the official python API. For now, both versions
+of the python API live side-by-side.
+</div>
+
+<h2 id="dataset">Dataset objects</h2>
+
+<p>
+Datasets can be obtained through <code>ir_datasts.load(<span class="str">"dataset-id"</span>)</code>
+or constructed with <code>ir_datasets.create_dataset(...)</code>. Dataset objects provide the
+following methods:
+</p>
+
+<h4><code>dataset.has_docs() -> bool</code></h4>
+
+<div class="methodinfo">
+<p>Returns <code class="kwd">True</code> if this dataset supports <code>dataset.docs_*</code> methods.</p>
+</div>
+
+<h4><code>dataset.has_queries() -> bool</code></h4>
+
+<div class="methodinfo">
+<p>Returns <code class="kwd">True</code> if this dataset supports <code>dataset.queries_*</code> methods.</p>
+</div>
+
+<h4><code>dataset.has_qrels() -> bool</code></h4>
+
+<div class="methodinfo">
+<p>Returns <code class="kwd">True</code> if this dataset supports <code>dataset.qrels_*</code> methods.</p>
+</div>
+
+<h4><code>dataset.has_scoreddocs() -> bool</code></h4>
+
+<div class="methodinfo">
+<p>Returns <code class="kwd">True</code> if this dataset supports <code>dataset.scoreddocs_*</code> methods.</p>
+</div>
+
+<h4><code>dataset.has_docpairs() -> bool</code></h4>
+
+<div class="methodinfo">
+<p>Returns <code class="kwd">True</code> if this dataset supports <code>dataset.docpairs_*</code> methods.</p>
+</div>
+
+
+<h4><code>iter(dataset.docs) -> iter[namedtuple]</code></h4>
+
+<div class="methodinfo">
+<p>Returns an iterator of <code>namedtuple</code>s, where each item is a document in the collection.</p>
+</div>
+
+<h4><code>len(dataset.docs) -> int</code></h4>
+
+<div class="methodinfo">
+<p>Returns the number of documents in the collection.</p>
+</div>
+
+<h4><code>dataset.docs[start:stop:skip] -> iter[namedtuple]</code></h4>
+
+<div class="methodinfo">
+<p>Returns an iterator of <code>namedtuple</code>s by index, specified by the slice given.</p>
+
+<code class="example">
+<div class="comment"># First 10 documents</div>
+<div>dataset.docs[:10]</div>
+
+<div class="comment"># Last 10 documents</div>
+<div>dataset.docs[-10:]</div>
+
+<div class="comment"># Every 2 documents</div>
+<div>dataset.docs[::2]</div>
+
+<div class="comment"># Every 2 documents, starting with the first document</div>
+<div>dataset.docs[1::2]</div>
+
+<div class="comment"># The first half of the collection</div>
+<div>dataset.docs[:1/2]</div>
+
+<div class="comment"># The middle third of collection</div>
+<div>dataset.docs[1/3:2/3]</div>
+</code>
+
+<p>
+Note that the fancy slicing mechanics are faster and more sophisticated than
+<code>itertools.islice</code>; documents are not processed if they are skipped.
+</p>
+</div>
+
+<h4><code>dataset.docs.type -> type</code></h4>
+
+<div class="methodinfo">
+<p>
+Returns the <code class="kwd">NamedTuple</code> type that the <code>docs_iter</code> returns.
+The available fields and type information can be found with <code>_fields</code> and <code>__annotations__</code>:
+</p>
+
+<code class="example">
+<div>dataset.docs.type._fields</div>
+</code>
+<code class="output">
+<div>(<span class="str">'doc_id'</span>, <span class="str">'title'</span>, <span class="str">'doi'</span>, <span class="str">'date'</span>, <span class="str">'abstract'</span>)</div>
+</code>
+<code class="example">
+<div>dataset.docs.type.__annotations__</div>
+</code>
+<code class="output">
+<div>{{</div>
+<div>&nbsp;&nbsp;<span class="str">'doc_id'</span>: <span class="kwd">str</span>,</div>
+<div>&nbsp;&nbsp;<span class="str">'title'</span>: <span class="kwd">str</span>,</div>
+<div>&nbsp;&nbsp;<span class="str">'doi'</span>: <span class="kwd">str</span>,</div>
+<div>&nbsp;&nbsp;<span class="str">'date'</span>: <span class="kwd">str</span>,</div>
+<div>&nbsp;&nbsp;<span class="str">'abstract'</span>: <span class="kwd">str</span></div>
+<div>}}</div>
+</code>
+</div>
+
+
+<h4><code>dataset.docs.lookup(doc_ids) -> Dict[str, namedtuple]</code></h4>
+
+<div class="methodinfo">
+<p>
+Returns a dictionary mapping all doc_ids found in the collection to their contents.
+</p>
+</div>
+
+<h4><code>dataset.docs.lookup_iter(doc_ids) -> Iterable[namedtuple]</code></h4>
+
+<div class="methodinfo">
+<p>
+Returns an iterable of all docs associated with the specified doc_ids found in the collection.
+</p>
+</div>
+
+<h4><code>dataset.docs.lang -> str</code></h4>
+
+<div class="methodinfo">
+<p>
+Returns the two-character <a href="https://en.wikipedia.org/wiki/ISO_639-1">ISO 639-1
+language code</a> (e.g., <span class="str">"en"</span> for English) of the documents in this collection.
+Returns <span class="kwd">None</span> if there are multiple languages, a language not represented by an
+ISO 639-1 code, or the language is otherwise unknown.
+</p>
+</div>
+
+
+<h4><code>iter(dataset.queries) -> iter[namedtuple]</code></h4>
+
+<div class="methodinfo">
+<p>
+Returns an iterator over namedtuples representing queries in the dataset.
+</p>
+</div>
+
+<h4><code>len(dataset.queries) -> int</code></h4>
+
+<div class="methodinfo">
+<p>
+Returns the number of queries in the dataset.
+</p>
+</div>
+
+
+<h4><code>dataset.queries.type -> type</code></h4>
+
+<div class="methodinfo">
+<p>
+Returns the type of the namedtuple returned by <code>iter(queries)</code>,
+including <code>_fields</code> and <code>__annotations__</code>.
+</p>
+</div>
+
+
+<h4><code>dataset.queries.lang -> str</code></h4>
+
+<div class="methodinfo">
+<p>
+Returns the two-character <a href="https://en.wikipedia.org/wiki/ISO_639-1">ISO 639-1
+language code</a> (e.g., <span class="str">"en"</span> for English) of the queries.
+Returns <span class="kwd">None</span> if there are multiple languages, a language not represented by an
+ISO 639-1 code, or the language is otherwise unknown. Note that some datasets include
+translations as different query fields.
+</p>
+</div>
+
+<h4><code>dataset.queries.lookup(query_ids) -> Dict[str, namedtuple]</code></h4>
+
+<div class="methodinfo">
+<p>
+Returns a dictionary mapping all query_ids found in the dataset to their contents.
+</p>
+</div>
+
+<h4><code>dataset.queries.lookup_iter(query_ids) -> Iterable[namedtuple]</code></h4>
+
+<div class="methodinfo">
+<p>
+Returns an iterable of all docs associated with the specified query_ids found in the dataset.
+</p>
+</div>
+
+
+<h4><code>iter(dataset.qrels) -> iter[namedtuple]</code></h4>
+
+<div class="methodinfo">
+<p>
+Returns an iterator over namedtuples representing query relevance assessments in the dataset.
+</p>
+</div>
+
+<h4><code>len(dataset.qrels) -> int</code></h4>
+
+<div class="methodinfo">
+<p>
+Returns the numer of qrels in the dataset.
+</p>
+</div>
+
+<h4><code>dataset.qrels.type -> type</code></h4>
+
+<div class="methodinfo">
+<p>
+Returns the type of the namedtuple returned by <code>qrels_iter</code>,
+including <code>_fields</code> and <code>__annotations__</code>.
+</p>
+</div>
+
+
+<h4><code>dataset.qrels.defs -> dict[int, str]</code></h4>
+
+<div class="methodinfo">
+<p>
+Returns a mapping between relevance levels and a textual description of
+what the level represents. (E.g., 0 represting not relevant, 1 representing
+possibly relevant, 2 representing definitely relevant.)
+</p>
+</div>
+
+
+<h4><code>dataset.qrels.asdict() -> dict[str, dict[str, int]]</code></h4>
+
+<div class="methodinfo">
+<p>
+Returns a dict of dicts representing all qrels for this collection. Note
+that this will load all qrels into memory. The outer dict key is the
+<code>query_id</code> and the inner key is the <code>doc_id</code>.
+This is useful in tools such as <a href="https://github.com/cvangysel/pytrec_eval">pytrec_eval</a>.
+</p>
+</div>
+
+
+<h4><code>iter(dataset.scoreddocs) -> iter[namedtuple]</code></h4>
+
+<div class="methodinfo">
+<p>
+Returns an iterator over namedtuples representing scored docs (e.g., initial rankings
+for re-ranking tasks) in the dataset.
+</p>
+</div>
+
+
+<h4><code>dataset.scoreddocs.type -> type</code></h4>
+
+<div class="methodinfo">
+<p>
+Returns the type of the namedtuple returned by <code>scoreddocs_iter</code>,
+including <code>_fields</code> and <code>__annotations__</code>.
+</p>
+</div>
+
+
+<h4><code>iter(dataset.docpairs) -> iter[namedtuple]</code></h4>
+
+<div class="methodinfo">
+<p>
+Returns an iterator over namedtuples representing doc pairs (e.g., training pairs) in the dataset.
+</p>
+</div>
+
+
+<h4><code>dataset.docpairs.type -> type</code></h4>
+
+<div class="methodinfo">
+<p>
+Returns the type of the namedtuple returned by <code>docpairs_iter</code>,
+including <code>_fields</code> and <code>__annotations__</code>.
+</p>
+</div>
 ''')
 
 
@@ -695,6 +1038,25 @@ until all documents are sent to fifos.
 ''')
 
 
+def generate_downloads(out_dir, version):
+    with page_template('downloads.html', out_dir, version, title='Download dashboard') as out:
+        out.write('''
+<div id="Downloads">
+</div>
+<script type="text/javascript">
+$(function () {
+    $.ajax({
+        'url': 'https://smac.pub/irdsdlc'
+    }).done(function (data) {
+        $.each(data, function (ds, downloads) {
+            $('#Downloads').append(generateDownloads(ds, downloads));
+        });
+    });
+});
+</script>
+''')
+
+
 @contextmanager
 def page_template(file, base_dir, version, title=None, source=None):
     with open(get_file_path(base_dir, version, file), 'wt') as out:
@@ -774,9 +1136,9 @@ jobs:
       env:
         IR_DATASETS_DL_DISABLE_PBAR: 'true'
       run: |
-        python -m test.downloads --filter "^{top}/" --output "{top}.json"
+        python -m test.downloads --filter "^{top}/" --output "{top}.json" --randdelay 60
     - name: Upload artifact
-      if: always() # don't skip if the Test step fails (defaults the whole purpose)
+      if: always() # don't skip if the Test step fails (defeats the whole purpose)
       uses: actions/upload-artifact@v2
       with:
         name: "{top}.json"
@@ -788,27 +1150,14 @@ jobs:
 def generate_css(base_dir, version):
     with open(get_file_path(base_dir, version, 'main.css'), 'wt') as out:
         out.write(r'''
-@font-face {
-  font-family: 'Titillium Web';
-  font-style: normal;
-  font-weight: 400;
-  src: local('Titillium Web'), local('TitilliumWeb-Regular'), 
-url("https://fonts.gstatic.com/s/titilliumweb/v4/7XUFZ5tgS-tD6QamInJTcRnhefaTZMTJ3r9AXhRp6aM.woff2") format('woff2');
-  unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2212, U+2215, U+E0FF, U+EFFD, U+F000;
-}
-@font-face {
-  font-family: 'Titillium Web';
-  font-style: normal;
-  font-weight: 600;
-  src: local('Titillium Web SemiBold'), local('TitilliumWeb-SemiBold'), url(https://fonts.gstatic.com/s/titilliumweb/v8/NaPDcZTIAOhVxoMyOr9n_E7ffBzCGItzY5abuWI.woff2) format('woff2');
-  unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
-}
+@import url('https://fonts.googleapis.com/css2?family=Roboto:wght@400;700&display=swap');
 body {
-  font-family: "Titillium Web", Calibri, Arial, sans-serif;
-  font-size: 13px;
+  font-family: "Roboto", Arial, sans-serif;
+  font-size: 14px;
   background-color: #eee;
   padding: 0;
   margin: 0;
+  line-height: 1.3;
 }
 .dataset {
   margin: 24px 0;
@@ -837,8 +1186,8 @@ body {
 .tag-scoreddocs { background-color: #9e5bd9; }
 .tag-docpairs { background-color: #06a892; }
 p, blockquote {
-  margin: 4px 0;
-  color: #666;
+  margin: 6px 0;
+  color: #333;
 }
 blockquote {
   border-left: 3px solid #a5bcd1;
@@ -846,7 +1195,7 @@ blockquote {
   margin-left: 6px;
 }
 .desc {
-  color: #666;
+  color: #333;
 }
 .ds-ref {
   font-family: monospace;
@@ -924,6 +1273,7 @@ cite {
   cursor: pointer;
   background-color: #666;
   color: white;
+  line-height: 1.5;
 }
 
 .tab.selected {
@@ -1052,7 +1402,7 @@ tbody tr:last-child td {
 
 .warn {
   color: white;
-  background-color: #ff9800;
+  background-color: #c17300;
   padding: 8px 16px;
   border-radius: 8px;
 }
@@ -1075,7 +1425,32 @@ h4 {
   top: 0;
 }
 
-@media screen and (max-width: 420px){
+details {
+    margin: 8px 0;
+}
+
+#DataAccess {
+    border: 1px solid #91b6ca;
+    margin: 8px;
+    padding: 6px;
+    background-color: #eff8fc;
+    border-radius: 4px;
+}
+
+#DataAccess h3 {
+    margin: 3px 0;
+}
+
+#Downloads {
+    min-height: 21px;
+    margin: 8px 0;
+}
+
+.screen-small-show {
+    display: none;
+}
+
+@media screen and (max-width: 500px){
   .page {
     padding: 6px;
     margin: 0;
@@ -1096,6 +1471,9 @@ h4 {
   .screen-small-hide {
     display: none;
   }
+  .screen-small-show {
+    display: inherit;
+  }
   .banner {
     margin-top: -6px;
     margin-left: -6px;
@@ -1159,7 +1537,77 @@ $(document).ready(function() {
         tabs.find('.tab.selected').removeClass('selected');
         $target.addClass('selected');
     });
+    $('#DatasetJump').change(function () {
+        var targetRow = $('#DatasetJump').val();
+        if (targetRow) {
+            $('#' + targetRow)[0].scrollIntoView();
+            $('#DatasetJump').val(''); // clear selection
+        }
+    });
 });
+function toEmoji(test) {
+    if (test) {
+        return '✅';
+    }
+    return '❌';
+}
+function toTime(duration) {
+    if (duration < 60) {
+        return duration.toFixed(2) + 's';
+    }
+    var minutes = Math.floor(duration / 60);
+    var seconds = duration % 60;
+    return minutes.toFixed(0) + 'm ' + seconds.toFixed(0) + 's';
+}
+function toFileSize(size) {
+    if (!size) {
+        return '';
+    }
+    var unit = 'B';
+    var units = ['KB', 'MB', 'GB'];
+    while (units.length > 0 && size > 1000) {
+        size = size / 1000;
+        unit = units.shift();
+    }
+    if (unit === 'B') {
+        size = size.toFixed(0);
+    } else {
+        size = size.toFixed(1);
+    }
+    return size + ' ' + unit;
+}
+function generateDownloads(title, downloads) {
+    if (downloads.length === 0) {
+        return $('<div></div>');
+    }
+    var allGood = true;
+    var $content = $('<table></table>');
+    $content.append($('<tr><th>Avail</th><th>Download ID</th><th>Size</th><th>Time</th><th>Last Tested At</th><th>Expected MD5 Hash</th></tr>'));
+    var goodCount = 0;
+    var totalCount = 0;
+    $.each(downloads, function (i, dl) {
+        var good = dl.result === "PASS";
+        totalCount += 1;
+        if (!good) {
+            allGood = false;
+        } else {
+            goodCount += 1;
+        }
+        $content.append($('<tr></tr>')
+            .append($('<td></td>').text(toEmoji(good)).attr('title', dl.result).css('text-align', 'center'))
+            .append($('<td></td>').append($('<a></a>').attr('href', dl.url).text(dl.name)))
+            .append($('<td></td>').text(toFileSize(dl.size)))
+            .append($('<td></td>').text(toTime(dl.duration)))
+            .append($('<td></td>').text(dl.time.substring(0, 19).replace('T', ' ')))
+            .append($('<td></td>').append($('<code>').text(dl.md5)))
+        );
+    });
+    return $('<details></details>')
+        .append($('<summary></summary>').text(toEmoji(allGood) + ' ' + title + ' (' + goodCount.toString() + ' of ' + totalCount.toString() + ')'))
+        .append($('<p>These files are automatically downloaded by ir_datasets as they are needed. We also periodically check that they are still available and unchanged through an automated <a href="https://github.com/allenai/ir_datasets/actions/workflows/verify_downloads.yml">GitHub action</a>. The latest results from that test are shown here:</p>'))
+        .append($content)
+        .prop('open', !allGood);
+}
 ''')
 
 
@@ -1179,12 +1627,12 @@ def generate_qrel_defs_table(defs):
 </table>
 '''
 
-def emoji(ds, arg):
+def emoji(ds, arg, top_level):
     has = getattr(ds, f'has_{arg}')()
     if has:
         instructions = hasattr(ds, f'documentation') and ds.documentation().get(f'{arg}_instructions')
         if instructions:
-            return f'<span style="cursor: help;" title="{instructions}">⚠️</span>'
+            return f'<a href="{top_level}.html#DataAccess" title="{instructions}. Click for details.">⚠️</a>'
         return f'<span style="cursor: help;" title="{arg} available as automatic download">✅</span>'
     return ''
 
