@@ -1,11 +1,15 @@
 from . import base
 from . import antique
 from . import aquaint
+from . import beir
 from . import car
 from . import clinicaltrials
+from . import clirmatrix
 from . import clueweb09
 from . import clueweb12
 from . import cord19
+from . import cranfield
+from . import dpr_w100
 from . import codesearchnet
 from . import gov
 from . import gov2
@@ -15,12 +19,15 @@ from . import msmarco_passage
 from . import msmarco_document
 from . import msmarco_qna
 from . import nfcorpus
-from . import trec_robust04
+from . import natural_questions
 from . import nyt
 from . import pmc
 from . import trec_arabic
 from . import trec_mandarin
 from . import trec_spanish
+from . import trec_robust04
+from . import tripclick
 from . import tweets2013_ia
 from . import vaswani
+from . import wapo
 from . import wikir
