@@ -17,6 +17,12 @@ class TrecDoc(NamedTuple):
     text: str
     marked_up_doc: str
 
+class TitleUrlTextDoc(NamedTuple):
+    doc_id: str
+    title: str
+    url: str
+    text: str
+
 class TrecQuery(NamedTuple):
     query_id: str
     title: str
@@ -45,7 +51,7 @@ class TrecPrel(NamedTuple):
 CONTENT_TAGS = 'TEXT HEADLINE TITLE HL HEAD TTL DD DATE LP LEADPARA'.split()
 
 class TrecDocs(BaseDocs):
-    def __init__(self, docs_dlc, encoding=None, path_globs=None, content_tags=CONTENT_TAGS, parser='BS4', namespace=None, lang=None):
+    def __init__(self, docs_dlc, encoding=None, path_globs=None, content_tags=CONTENT_TAGS, parser='BS4', namespace=None, lang=None, expected_file_count=None):
         self._docs_dlc = docs_dlc
         self._encoding = encoding
         self._path_globs = path_globs
@@ -53,13 +59,18 @@ class TrecDocs(BaseDocs):
         self._parser = {
             'BS4': self._parser_bs,
             'text': self._parser_text,
+            'tut': self._parser_tut,
         }[parser]
         self._doc = {
             'BS4': TrecDoc,
             'text': GenericDoc,
+            'tut': TitleUrlTextDoc,
         }[parser]
         self._docs_namespace = namespace
         self._docs_lang = lang
+        self._expected_file_count = expected_file_count
+        if expected_file_count is not None:
+            assert self._path_globs is not None, "expected_file_count only supported with path_globs"
 
     def docs_path(self):
         return self._docs_dlc.path()
@@ -68,13 +79,19 @@ class TrecDocs(BaseDocs):
     def docs_iter(self):
         if Path(self._docs_dlc.path()).is_dir():
             if self._path_globs:
+                file_count = 0
                 for glob in sorted(self._path_globs):
                     for path in sorted(Path(self._docs_dlc.path()).glob(glob)):
+                        file_count += 1
                         yield from self._docs_iter(path)
+                if self._expected_file_count is not None:
+                    if file_count != self._expected_file_count:
+                        raise RuntimeError(f'found {file_count} files of the expected {self._expected_file_count} matching the following: {self._path_globs} under {self._docs_dlc.path()}. Make sure that directories are linked such that these globs match the correct number of files.')
             else:
                 yield from self._docs_iter(self._docs_dlc.path())
         else:
             if self._path_globs:
+                file_count = 0
                 # tarfile, find globs, open in streaming mode (r|)
                 with self._docs_dlc.stream() as stream:
                     with tarfile.open(fileobj=stream, mode='r|gz') as tarf:
@@ -84,6 +101,10 @@ class TrecDocs(BaseDocs):
                                 if block.name.endswith('.gz'):
                                     file = gzip.GzipFile(fileobj=file)
                                 yield from self._parser(file)
+                                file_count += 1
+                if self._expected_file_count is not None:
+                    if file_count != self._expected_file_count:
+                        raise RuntimeError(f'found {file_count} files of the expected {self._expected_file_count} matching the following: {self._path_globs} under {self._docs_dlc.path()}. Make sure that directories are linked such that these globs match the correct number of files.')
             else:
                 with self._docs_dlc.stream() as f:
                     yield from self._parser(f)
@@ -145,6 +166,28 @@ class TrecDocs(BaseDocs):
                     if any(line.startswith(f'<{tag}>') for tag in self._content_tags):
                         in_tag = True
 
+    def _parser_tut(self, stream):
+        f = codecs.getreader(self._encoding or 'utf8')(stream, errors='replace')
+        doc_id, doc_title, doc_url, doc_text = None, None, None, ''
+        in_tag = False
+        for line in f:
+            if line.startswith('<DOCNO>'):
+                doc_id = line.replace('<DOCNO>', '').replace('</DOCNO>\n', '').strip()
+            if line.startswith('<TITLE>'):
+                doc_title = line.replace('<TITLE>', '').replace('</TITLE>\n', '').strip()
+            if line.startswith('<URL>'):
+                doc_url = line.replace('<URL>', '').replace('</URL>\n', '').strip()
+            elif line == '</DOC>\n':
+                yield TitleUrlTextDoc(doc_id, doc_title, doc_url, doc_text)
+                doc_id, doc_title, doc_url, doc_text = None, None, None, ''
+            else:
+                if line.startswith('</TEXT>'):
+                    in_tag = False
+                if in_tag:
+                    doc_text += line
+                if line.startswith('<TEXT>'):
+                    in_tag = True
+
     def docs_cls(self):
         return self._doc
 
